/*
 * DemosceneMusic - Group.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.data;

import java.util.Collection;

/**
 * Data interface for groups.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public interface Group extends Base {

	/**
	 * Returns the name of this group.
	 *
	 * @return The name of this group
	 */
	public String getName();

	/**
	 * Sets the name of this group.
	 *
	 * @param name
	 *            The name of this group
	 * @return This group
	 */
	public Group setName(String name);

	/**
	 * Returns the URL of this group’s website.
	 *
	 * @return The URL of this group’s website
	 */
	public String getUrl();

	/**
	 * Sets the URL of this group’s website.
	 *
	 * @param url
	 *            The URL of this group’s website
	 * @return This group
	 */
	public Group setUrl(String url);

	/**
	 * Returns all artists belonging to this group.
	 *
	 * @return All artists belonging to this group
	 */
	public Collection<Artist> getArtists();

	/**
	 * Sets all artists belonging to this group.
	 *
	 * @param artists
	 *            All artists belonging to this group
	 * @return This group
	 */
	public Group setArtists(Collection<Artist> artists);

}
