/*
 * DemosceneMusic - AddArtistPage.java - Copyright © 2012 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.demoscenemusic.page.admin;

import net.pterodactylus.demoscenemusic.core.Core;
import net.pterodactylus.demoscenemusic.data.Artist;
import net.pterodactylus.demoscenemusic.page.ServletRequest;
import net.pterodactylus.util.database.DatabaseException;
import net.pterodactylus.util.template.Template;
import net.pterodactylus.util.template.TemplateContext;
import net.pterodactylus.util.template.TemplateContextFactory;
import net.pterodactylus.util.web.Method;
import net.pterodactylus.util.web.RedirectException;

/**
 * Page that lets the user add an artist.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class AddArtistPage extends AdminBasePage {

	/**
	 * Creates a new “add artist” page.
	 *
	 * @param core
	 *            The core
	 * @param templateContextFactory
	 *            The template context factory
	 * @param template
	 *            The template to render
	 */
	public AddArtistPage(Core core, TemplateContextFactory templateContextFactory, Template template) {
		super(core, templateContextFactory, template, "admin.add-artist");
	}

	//
	// BASEPAGE METHODS
	//

	/**
	 * {@inheritDoc}
	 */
	@Override
	protected void processTemplate(TemplateContext templateContext, ServletRequest request) throws RedirectException {
		super.processTemplate(templateContext, request);
		if (request.getMethod() == Method.POST) {
			String name = request.getServletRequest().getParameter("name").trim();
			if (name.length() == 0) {
				templateContext.set("error", "no-name-given");
				return;
			}
			try {
				Artist artist = getCore().getDataManager().createArtist(name);
				throw new RedirectException("admin.edit-artist?id=" + artist.getId());
			} catch (DatabaseException de1) {
				throw new RuntimeException("Could not create artist.", de1);
			}
		}
	}

}
